<?php

namespace Drupal\eca_misc\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;
use Drupal\eca\Plugin\Action\ConfigurableActionBase;

/**
 * Gets a flagging entity for a content entity and stores it as a token.
 *
 * @Action(
 *   id = "entity_id_key",
 *   label = @Translation("Get the entity ID with its key."),
 *   description = @Translation("Get entity type ID key."),
 *   eca_version_introduced = "1.0.0",
 *   type = "entity"
 * )
 */
class EntityIdKey extends ConfigurableActionBase {
  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
        'token_name_entity_type_id_key' => '',
        'provided_entity' => '',
      ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = [];
    $form = parent::buildConfigurationForm($form, $form_state);

    $form['token_name_entity_type_id_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Token name for the entity type ID key'),
      '#description' => $this->t('The name of the token that holds the entity type ID key value.'),
      '#default_value' => $this->configuration['token_name_entity_type_id_key'],
      '#eca_token_select_option' => FALSE,
    ];
    $form['provided_entity'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Entity'),
      '#description' => $this->t('The name of the token that holds the entity.'),
      '#default_value' => $this->configuration['provided_entity'],
      '#required' => FALSE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['token_name_entity_type_id_key'] = $form_state->getValue('token_name_entity_type_id_key');
    $this->configuration['provided_entity'] = $form_state->getValue('provided_entity');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function execute(mixed $entity = NULL): void {
    $entity_type_id = $entity->getEntityTypeId();
    $token_name = $this->configuration['token_name_entity_type_id_key'];
    $entity_definition = $this->entityTypeManager->getDefinition($entity_type_id);

    $this->tokenService->addTokenData($token_name, $entity_definition->getKey('id'));
  }

}
